@@ -1,42 +1,42 @@
 def return_function(node):
     if node["data"]["value"] == "Remove NAN values":
-        return remove_nan_values(node['data']['parameters'])
+        return temp_remove_nan_values(node['data']['parameters'])
     elif node["data"]["value"] == "Replace NAN values":
-        return replace_nan_values(node['data']['parameters'])
+        return temp_replace_nan_values(node['data']['parameters'])
     elif node["data"]["value"] == "Dropping rows or columns":
-        return drop_rows_columns(node['data']['parameters'])
+        return temp_drop_rows_columns(node['data']['parameters'])
     elif node["data"]["value"] == "Remove Outliers":
-        return remove_outliers(node['data']['parameters'])
+        return temp_remove_outliers(node['data']['parameters'])
     elif node["data"]["value"] == "Drop Duplicates":
-        return drop_duplicates(node['data']['parameters'])
+        return temp_drop_duplicates(node['data']['parameters'])
     elif node["data"]["value"] == "Change Data Type":
-        return change_data_type(node['data']['parameters'])
+        return temp_change_data_type(node['data']['parameters'])
     elif node["data"]["value"] == "Round Data":
-        return round_data(node['data']['parameters'])
+        return temp_round_data(node['data']['parameters'])
     elif node["data"]["value"] == "Filter DataFrame":
-        return filter_dataframe(node['data']['parameters'])
+        return temp_filter_dataframe(node['data']['parameters'])
     elif node["data"]["value"] == "Truncate DataFrame":
-        return truncate_dataframe(node['data']['parameters'])
+        return temp_truncate_dataframe(node['data']['parameters'])
     elif node["data"]["value"] == "Sort Values":
-        return sort_values(node['data']['parameters'])
+        return temp_sort_values(node['data']['parameters'])
     elif node["data"]["value"] == "Transpose DataFrame":
-        return transpose()
+        return temp_transpose()
     elif node["data"]["value"] == "Min Max Scaler":
-        return min_max_scale(node['data']['parameters'])
+        return temp_min_max_scale(node['data']['parameters'])
     elif node["data"]["value"] == "Max Abs Scaler":
-        return max_abs_scale(node['data']['parameters'])
+        return temp_max_abs_scale(node['data']['parameters'])
     elif node["data"]["value"] == "Robust Scaler":
-        return robust_scale(node['data']['parameters'])
+        return temp_robust_scale(node['data']['parameters'])
     elif node["data"]["value"] == "Standard Scaler":
-        return standard_scale(node['data']['parameters'])
+        return temp_standard_scale(node['data']['parameters'])
     elif node["data"]["value"] == "Normalization":
-        return normalize(node['data']['parameters'])
+        return temp_normalize(node['data']['parameters'])
     elif node["data"]["value"] == "Ordinal Encoding":
-        return ordinal_encode(node['data']['parameters'])
+        return temp_ordinal_encode(node['data']['parameters'])
     elif node["data"]["value"] == "One Hot Encoding":
-        return one_hot_encode(node['data']['parameters'])
+        return temp_one_hot_encode(node['data']['parameters'])
 
-def remove_nan_values(params):
+def temp_remove_nan_values(params):
     subset=[]
     for i in range(len(params['subset'])):
         subset.append(params['subset'][i]['value'])
@@ -49,7 +49,7 @@ def remove_nan_values(params):
     return f"data = huble.sklearn.remove_nan_values(data=data,parameters={parameters})"
 
 
-def replace_nan_values(params):
+def temp_replace_nan_values(params):
     parameters = {
         "missing_values" : params['missing_values'], 
         "strategy" : params['strategy'],
@@ -57,7 +57,7 @@ def replace_nan_values(params):
     }
     return f"data = huble.sklearn.replace_nan_values(data=data, column='{params['column']}', parameters={parameters})"
 
-def drop_rows_columns(params):
+def temp_drop_rows_columns(params):
     labels=[]
     for i in range(len(params['labels'])):
         labels.append(params['labels'][i]['value'])
@@ -70,10 +70,10 @@ def drop_rows_columns(params):
     }
     return f"data = huble.sklearn.drop_rows_columns(data=data,parameters={parameters})"
 
-def remove_outliers(params):
+def temp_remove_outliers(params):
     return f"data = huble.sklearn.remove_outliers(data=data,columns='{params['columns']}')"
 
-def drop_duplicates(params):
+def temp_drop_duplicates(params):
     subset=[]
     for i in range(len(params['subset'])):
         subset.append(params['subset'][i]['value'])
@@ -86,7 +86,7 @@ def drop_duplicates(params):
     return f"data = huble.sklearn.drop_duplicates(data=data,parameters={parameters})"
 
 
-def change_data_type(params):
+def temp_change_data_type(params):
     parameters = {
         "dtype" : params['data type'], 
         "copy" : params['copy'], 
@@ -95,14 +95,14 @@ def change_data_type(params):
     return f"data = huble.sklearn.change_data_type(data=data,column={params['column']}, parameters={parameters})"
 
 
-def round_data(params):
+def temp_round_data(params):
     parameters = {
         "decimals" : params['decimals'],
     }
     return f"data = huble.sklearn.round_data(data=data, parameters={parameters})"
 
 
-def filter_dataframe(params):
+def temp_filter_dataframe(params):
     items=[]
     for i in range(len(params['items'])):
         items.append(params['items'][i]['value'])
@@ -114,7 +114,7 @@ def filter_dataframe(params):
     return f"data = huble.sklearn.filter_dataframe(data=data, parameters={parameters})"
 
 
-def truncate_dataframe(params):
+def temp_truncate_dataframe(params):
     parameters = {
         "before" : params['before'], 
         "after" : params['after'], 
@@ -124,7 +124,7 @@ def truncate_dataframe(params):
     return f"data = huble.sklearn.truncate_datfarame(data=data, parameters={parameters})"
 
 
-def sort_values(params):
+def temp_sort_values(params):
     by=[]
     for i in range(len(params['by'])):
         by.append(params['by'][i]['value'])
@@ -140,11 +140,11 @@ def sort_values(params):
     return f"data = huble.sklearn.sort_values(data=data, parameters={parameters})"
 
 
-def transpose():
+def temp_transpose():
     return f"data = huble.sklearn.transpose(data=data)"
 
 
-def min_max_scale(params):
+def temp_min_max_scale(params):
     parameters = {
         "feature_range" : params['feature_range'], 
         "copy" : params['copy'], 
@@ -153,14 +153,14 @@ def min_max_scale(params):
     return f"data = huble.sklearn.min_max_scalar(data=data, columns={params['columns']}, parameters={parameters})"
 
 
-def max_abs_scale(params):
+def temp_max_abs_scale(params):
     parameters = {
         "copy" : params['copy'],
     }
     return f"data = huble.sklearn.max_abs_scalar(data=data, columns={params['columns']}, parameters={parameters})"
 
 
-def robust_scale(params):
+def temp_robust_scale(params):
     columns=[]
     for i in range(len(params['column'])):
         columns.append(params['column'][i]['value'])
@@ -174,7 +174,7 @@ def robust_scale(params):
     return f"data = huble.sklearn.robust_scalar(data=data, column={columns}, parameters={parameters})"
 
 
-def standard_scale(params):
+def temp_standard_scale(params):
     parameters = {
         "copy" : params['copy'], 
         "with_mean" : params['with_mean'], 
@@ -183,7 +183,7 @@ def standard_scale(params):
     return f"data = huble.sklearn.standard_scalar(data=data, column={params['column']}, parameters={parameters})"
 
 
-def normalize(params):
+def temp_normalize(params):
     parameters = {
         "X" : params['column'], 
         "norm" : params['norm'], 
@@ -192,7 +192,7 @@ def normalize(params):
     return f"data = huble.sklearn.normalize(data=data, parameters={parameters})"
 
 
-def ordinal_encode(params):
+def temp_ordinal_encode(params):
     columns=[]
     for i in range(len(params['columns'])):
         columns.append(params['columns'][i]['value'])
@@ -206,7 +206,7 @@ def ordinal_encode(params):
     return f"data = huble.sklearn.ordinal_encode(data=data, columns={columns}, parameters={parameters})"
 
 
-def one_hot_encode(params):
+def temp_one_hot_encode(params):
     columns=[]
     for i in range(len(params['columns'])):
         columns.append(params['columns'][i]['value'])
